"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const utils_1 = require("../utils");
const fileSystemHandler_1 = require("../utils/fileSystemHandler");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
class ApexProcessor {
    constructor(metadataInfo, connection) {
        this.metadataInfo = metadataInfo;
        this.connection = connection;
        switch (metadataInfo.metadataName) {
            case 'ApexClass':
                this.cacheFolder = 'classes';
                break;
            case 'ApexTrigger':
                this.cacheFolder = 'triggers';
                break;
        }
    }
    async getMetadata() {
        let cachedFilePath;
        try {
            const queryResult = (await this.connection.tooling.query(this.buildQuery()));
            if (queryResult && queryResult.records.length === 0) {
                const username = await utils_1.usernameHandler.getUsername();
                throw new Error(messages.getMessage('error_md_not_present_in_org', [
                    this.getMdFileName(),
                    username
                ]));
            }
            cachedFilePath = await this.getCachedFilePath();
            fileSystemHandler_1.createMdCacheFile(cachedFilePath, queryResult.records[0].Body);
        }
        catch (err) {
            throw new Error(messages.getMessage('error_in_processor', ['ApexProcessor', err]));
        }
        return cachedFilePath;
    }
    async getCachedFilePath() {
        return await utils_1.createCacheFilePath(this.cacheFolder, this.getMdFileName());
    }
    getMdFileName() {
        return `${this.metadataInfo.fileName}.${this.metadataInfo.suffix}`;
    }
    buildQuery() {
        return `Select Id, Name, Body from ${this.metadataInfo.metadataName} where Name='${this.metadataInfo.fileName}'`;
    }
}
exports.default = ApexProcessor;
//# sourceMappingURL=apexProcessor.js.map