"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const command_1 = require("@salesforce/command");
const utils_1 = require("../utils");
const fileSystemHandler_1 = require("../utils/fileSystemHandler");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
class LWCProcessor {
    constructor(metadataInfo, connection) {
        this.metadataInfo = metadataInfo;
        this.connection = connection;
        this.cacheFolder = 'lwc';
    }
    async getMetadata() {
        let cachedFilePath;
        try {
            const queryResult = (await this.connection.tooling.query(this.buildQuery()));
            if (queryResult && queryResult.records.length === 0) {
                const username = await utils_1.usernameHandler.getUsername();
                throw new Error(messages.getMessage('error_md_not_present_in_org', [
                    this.getMdFileName(),
                    username
                ]));
            }
            cachedFilePath = await this.getCachedFilePath();
            fileSystemHandler_1.createMdCacheFile(cachedFilePath, queryResult.records[0].Source);
        }
        catch (err) {
            throw new Error(messages.getMessage('error_in_processor', ['LWCProcessor', err]));
        }
        return cachedFilePath;
    }
    /**
     * Build the value in lwcResource[0].filePath
     * NOTE: we do not use path.join here cause it does not change based on OS.
     */
    getMDFilePath() {
        return `${this.cacheFolder}/${this.metadataInfo.fileName}/${this.getMdFileName()}`;
    }
    async getCachedFilePath() {
        return await utils_1.createBundleCacheFilePath(this.cacheFolder, this.metadataInfo.fileName, this.getMdFileName());
    }
    getMdFileName() {
        return `${this.metadataInfo.fileName}.${this.metadataInfo.suffix}`;
    }
    buildQuery() {
        return `Select Id, LightningComponentBundleId, LightningComponentBundle.DeveloperName, FilePath, Source from ${this.metadataInfo.metadataName} where LightningComponentBundle.DeveloperName = '${this.metadataInfo.fileName}' and FilePath = '${this.getMDFilePath()}'`;
    }
}
exports.default = LWCProcessor;
//# sourceMappingURL=lwcProcessor.js.map